@@ -143,7 +143,10 @@ void ApplyProgressDialog::show()
 
     dialogWidget().treeTasks().clear();
     okButton->setVisible(false);
+    okButton->setEnabled(false);
     cancelButton->setVisible(true);
+    cancelButton->setEnabled(true);
+
 
     timer().start(1000);
     time().start();
@@ -194,24 +197,21 @@ void ApplyProgressDialog::onCancelButton()
         if (operationRunner().isCancelling())
             return;
 
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-        cancelButton->setEnabled(false);
-        setStatus(xi18nc("@info:progress", "Waiting for operation to finish..."));
-        repaint();
-        dialogWidget().repaint();
-
         // suspend the runner, so it doesn't happily carry on while the user decides
         // if he really wants to cancel
         operationRunner().suspendMutex().lock();
-        cancelButton->setEnabled(true);
-
-        QApplication::restoreOverrideCursor();
 
         if (KMessageBox::questionYesNo(this, xi18nc("@info", "Do you really want to cancel?"), xi18nc("@title:window", "Cancel Running Operations"), KGuiItem(xi18nc("@action:button", "Yes, Cancel Operations"), QStringLiteral("dialog-ok")), KStandardGuiItem::no()) == KMessageBox::Yes)
             // in the meantime while we were showing the messagebox, the runner might have finished.
-            if (operationRunner().isRunning())
+            if (operationRunner().isRunning()) {
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                cancelButton->setEnabled(false);
+                setStatus(xi18nc("@info:progress", "Waiting for operation to finish..."));
+                repaint();
+                dialogWidget().repaint();
+                QApplication::restoreOverrideCursor();
                 operationRunner().cancel();
+            }
 
         operationRunner().suspendMutex().unlock();
     }
@@ -245,6 +245,7 @@ void ApplyProgressDialog::allOpsDone(const QString& msg)
     dialogWidget().progressTotal().setValue(operationRunner().numJobs());
     cancelButton->setVisible(false);
     okButton->setVisible(true);
+    okButton->setEnabled(true);
     detailsWidget().buttonSave().setEnabled(true);
     detailsWidget().buttonBrowser().setEnabled(true);
     timer().stop();
@@ -365,7 +366,7 @@ void ApplyProgressDialog::addTaskOutput(int num, const Operation& op)
     item->setFont(0, f);
     item->setFont(1, f);
 
-    item->setData(0, Qt::UserRole, reinterpret_cast<const qulonglong>(&op));
+    item->setData(0, Qt::UserRole, reinterpret_cast<qulonglong>(&op));
     dialogWidget().treeTasks().addTopLevelItem(item);
     dialogWidget().treeTasks().scrollToBottom();
     setCurrentOpItem(item);
