@@ -17,14 +17,13 @@
 
 #include "gui/editmountoptionsdialogwidget.h"
 
-#include <QString>
-#include <QPlainTextEdit>
+#include <QStringList>
 
 EditMountOptionsDialogWidget::EditMountOptionsDialogWidget(QWidget* parent, const QStringList& options) :
     QWidget(parent)
 {
     setupUi(this);
 
-    foreach(const QString & o, options)
-    editOptions().appendPlainText(o);
+    for (const auto &o : options)
+        editOptions().appendPlainText(o);
 }
