@@ -28,6 +28,12 @@ class Partition;
 class QWidget;
 class QString;
 
+enum class MountPointAction
+{
+    Remove,
+    Edit
+};
+
 class EditMountPointDialog : public QDialog
 {
 public:
@@ -39,7 +45,7 @@ protected:
         return *m_DialogWidget;
     }
 
-    void accept() override;
+    void accept_(MountPointAction action);
 
 private:
     Partition& partition() {
