@@ -33,7 +33,7 @@
 #include <QPointer>
 #include <QString>
 
-EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Partition& p) :
+EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, Partition& p) :
     QWidget(parent),
     m_Partition(p)
 {
@@ -42,7 +42,7 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
     setupUi(this);
 
     m_deviceNode = partition().deviceNode();
-    if (partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Luks) {
+    if (partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Type::Luks) {
         const FS::luks* luksFs = dynamic_cast<const FS::luks*>(&partition().fileSystem());
         m_deviceNode = luksFs->mapperName();
     }
@@ -50,12 +50,14 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
     labelType().setText(partition().fileSystem().name());
 
     bool entryFound = false;
+    editPath().setEditable(true);
     for (auto &e : m_fstabEntries) {
         QString canonicalEntryPath = QFileInfo(e.deviceNode()).canonicalFilePath();
         QString canonicalDevicePath = QFileInfo(m_deviceNode).canonicalFilePath();
-        if (canonicalEntryPath == canonicalDevicePath) { // FIXME fix multiple mountpoints
+        if (canonicalEntryPath == canonicalDevicePath) {
             entryFound = true;
-            entry = &e;
+            entry.push_back(&e);
+            mountPointList = possibleMountPoints(e.deviceNode());
         }
     }
 
@@ -63,49 +65,24 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
         FileSystem::Type type = partition().fileSystem().type();
         QString fsName;
         switch (type) {
-        case FileSystem::LinuxSwap:
+        case FileSystem::Type::LinuxSwap:
             fsName = QStringLiteral("swap");
             break;
-        case FileSystem::Fat16:
-        case FileSystem::Fat32:
+        case FileSystem::Type::Fat16:
+        case FileSystem::Type::Fat32:
             fsName = QStringLiteral("vfat");
             break;
         default:
             fsName = partition().fileSystem().name();
         }
 
-        m_fstabEntries.append(FstabEntry(m_deviceNode, QString(), fsName, QString()));
-        entry = &m_fstabEntries.last();
-    }
-
-    editPath().setText(entry->mountPoint());
-
-    spinDumpFreq().setValue(entry->dumpFreq());
-    spinPassNumber().setValue(entry->passNumber());
-
-    switch (entry->entryType()) {
-    case FstabEntryType::uuid:
-        radioUUID().setChecked(true);
-        break;
-
-    case FstabEntryType::label:
-        radioLabel().setChecked(true);
-        break;
-
-    case FstabEntryType::partuuid:
-        radioUUID().setChecked(true);
-        break;
-
-    case FstabEntryType::partlabel:
-        radioLabel().setChecked(true);
-        break;
-
-    case FstabEntryType::deviceNode:
-        radioDeviceNode().setChecked(true);
-        break;
-    case FstabEntryType::comment:
-        break;
+        m_fstabEntries.push_back(FstabEntry(m_deviceNode, QString(), fsName, QString()));
+        entry.push_back(&m_fstabEntries.back());
     }
+    currentEntry = entry[0];
+    editPath().addItems(mountPointList);
+    spinDumpFreq().setValue(currentEntry->dumpFreq());
+    spinPassNumber().setValue(currentEntry->passNumber());
 
     boxOptions()[QStringLiteral("ro")] = m_CheckReadOnly;
     boxOptions()[QStringLiteral("users")] = m_CheckUsers;
@@ -116,8 +93,42 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
     boxOptions()[QStringLiteral("noexec")] = m_CheckNoExec;
     boxOptions()[QStringLiteral("relatime")] = m_CheckRelAtime;
 
-    setupOptions(entry->options());
+    setupRadio(currentEntry->entryType());
+    setupOptions(currentEntry->options());
 
+    connect(m_ButtonMore, &QPushButton::clicked, this, &EditMountPointDialogWidget::buttonMoreClicked);
+    connect(m_ButtonSelect, &QPushButton::clicked, this, &EditMountPointDialogWidget::buttonSelectClicked);
+    connect(m_EditPath, QOverload<int>::of(&QComboBox::currentIndexChanged),
+        [=](int index){ currentEntry = entry[index];
+                        spinDumpFreq().setValue(currentEntry->dumpFreq());
+                        spinPassNumber().setValue(currentEntry->passNumber());
+                        setupRadio(currentEntry->entryType());
+                        for (iterator_BoxOptions = boxOptions().begin(); iterator_BoxOptions != boxOptions().end(); ++iterator_BoxOptions){
+                            boxOptions()[iterator_BoxOptions->first]->setChecked(false);
+                        }
+                        setupOptions(currentEntry->options());
+                      });
+}
+
+EditMountPointDialogWidget::~EditMountPointDialogWidget()
+{
+}
+
+void EditMountPointDialogWidget::setupOptions(const QStringList& options)
+{
+    QStringList optTmpList;
+    for (const auto &o : options) {
+        if (boxOptions().find(o) != boxOptions().end())
+            boxOptions()[o]->setChecked(true);
+        else
+            optTmpList.append(o);
+    }
+
+    m_Options = optTmpList.join(QLatin1Char(','));
+}
+
+void EditMountPointDialogWidget::setupRadio(const FstabEntry::Type entryType)
+{
     if (partition().fileSystem().uuid().isEmpty()) {
         radioUUID().setEnabled(false);
         if (radioUUID().isChecked())
@@ -129,34 +140,60 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
         if (radioLabel().isChecked())
             radioDeviceNode().setChecked(true);
     }
+    switch (entryType) {
+    case FstabEntry::Type::uuid:
+        radioUUID().setChecked(true);
+        break;
 
-    connect(m_ButtonMore, &QPushButton::clicked, this, &EditMountPointDialogWidget::buttonMoreClicked);
-    connect(m_ButtonSelect, &QPushButton::clicked, this, &EditMountPointDialogWidget::buttonSelectClicked);
-}
+    case FstabEntry::Type::label:
+        radioLabel().setChecked(true);
+        break;
 
-EditMountPointDialogWidget::~EditMountPointDialogWidget()
-{
-}
+    case FstabEntry::Type::partuuid:
+        radioUUID().setChecked(true);
+        break;
 
-void EditMountPointDialogWidget::setupOptions(const QStringList& options)
-{
-    QStringList optTmpList;
+    case FstabEntry::Type::partlabel:
+        radioLabel().setChecked(true);
+        break;
 
-    for (const auto &o : options) {
-        if (boxOptions().find(o) != boxOptions().end())
-            boxOptions()[o]->setChecked(true);
-        else
-            optTmpList.append(o);
+    case FstabEntry::Type::deviceNode:
+        radioDeviceNode().setChecked(true);
+        break;
+    case FstabEntry::Type::comment:
+        break;
     }
-
-    m_Options = optTmpList.join(QLatin1Char(','));
 }
 
 void EditMountPointDialogWidget::buttonSelectClicked(bool)
 {
-    const QString s = QFileDialog::getExistingDirectory(this, editPath().text());
+    const QString s = QFileDialog::getExistingDirectory(this, editPath().currentText());
     if (!s.isEmpty())
-        editPath().setText(s);
+        editPath().setCurrentText(s);
+}
+
+void EditMountPointDialogWidget::removeMountPoint()
+{
+    for (auto it = fstabEntries().begin(); it != fstabEntries().end(); ) {
+        if (editPath().count() <= 1 && (
+                (it->fsSpec().contains(partition().deviceNode()) && !partition().deviceNode().isEmpty() ) ||
+                (it->fsSpec().contains(partition().fileSystem().uuid()) && !partition().fileSystem().uuid().isEmpty() ) ||
+                (it->fsSpec().contains(partition().fileSystem().label()) && !partition().fileSystem().label().isEmpty()) || 
+                (it->fsSpec().contains(partition().label()) && !partition().label().isEmpty() ) ||
+                (it->fsSpec().contains(partition().uuid()) && !partition().uuid().isEmpty() )))
+        {
+            fstabEntries().erase(it);
+            partition().setMountPoint(QString());
+        }
+        else if (editPath().count() > 1 && ((&*it == currentEntry)))
+        {
+            fstabEntries().erase(it);
+            editPath().removeItem(editPath().currentIndex());
+            partition().setMountPoint(editPath().itemText(editPath().currentIndex()));
+            break;
+        }
+    }
+
 }
 
 void EditMountPointDialogWidget::buttonMoreClicked(bool)
@@ -183,15 +220,15 @@ QStringList EditMountPointDialogWidget::options() const
 
 void EditMountPointDialogWidget::acceptChanges()
 {
-    entry->setDumpFreq(spinDumpFreq().value());
-    entry->setPassNumber(spinPassNumber().value());
-    entry->setMountPoint(editPath().text());
-    entry->setOptions(options());
+    currentEntry->setDumpFreq(spinDumpFreq().value());
+    currentEntry->setPassNumber(spinPassNumber().value());
+    currentEntry->setMountPoint(editPath().currentText());
+    currentEntry->setOptions(options());
 
     if (radioUUID().isChecked() && !partition().fileSystem().uuid().isEmpty())
-        entry->setFsSpec(QStringLiteral("UUID=") + partition().fileSystem().uuid());
+        currentEntry->setFsSpec(QStringLiteral("UUID=") + partition().fileSystem().uuid());
     else if (radioLabel().isChecked() && !partition().fileSystem().label().isEmpty())
-        entry->setFsSpec(QStringLiteral("LABEL=") + partition().fileSystem().label());
+        currentEntry->setFsSpec(QStringLiteral("LABEL=") + partition().fileSystem().label());
     else
-        entry->setFsSpec(m_deviceNode);
+        currentEntry->setFsSpec(m_deviceNode);
 }
