@@ -32,14 +32,14 @@ class Partition;
 class QFile;
 class QSpinBox;
 class QCheckBox;
-class QLineEdit;
+class QComboBox;
 class QPushButton;
 class QStringList;
 
 class EditMountPointDialogWidget : public QWidget, public Ui::EditMountPointDialogWidgetBase
 {
 public:
-    EditMountPointDialogWidget(QWidget* parent, const Partition& p);
+    EditMountPointDialogWidget(QWidget* parent, Partition& p);
     ~EditMountPointDialogWidget();
 
     QPushButton& buttonMore() {
@@ -48,7 +48,7 @@ public:
     QLabel& labelName() {
         return *m_LabelNameValue;
     }
-    QLineEdit& editPath() {
+    QComboBox& editPath() {
         return *m_EditPath;
     }
     QSpinBox& spinDumpFreq() {
@@ -75,6 +75,7 @@ public:
     }
 
     void acceptChanges();
+    void removeMountPoint();
     bool writeMountpoints(const QString& filename);
 
 protected:
@@ -83,6 +84,7 @@ protected:
 
 private:
     void setupOptions(const QStringList& options);
+    void setupRadio(const FstabEntry::Type entryType);
     std::map<QString, QCheckBox*>& boxOptions() {
         return m_BoxOptions;
     }
@@ -90,18 +92,24 @@ private:
         return m_BoxOptions;
     }
 
+    Partition& partition() {
+        return m_Partition;
+    }
+
     const Partition& partition() const {
         return m_Partition;
     }
 
 private:
     FstabEntryList m_fstabEntries;
-    FstabEntry *entry;
-
-    const Partition& m_Partition;
+    QList<FstabEntry *> entry; // All fstab entries for this partition
+    FstabEntry *currentEntry;
+    Partition& m_Partition;
     QString m_Options;
     QString m_deviceNode;
+    QStringList mountPointList;
     std::map<QString, QCheckBox*> m_BoxOptions;
+    std::map<QString, QCheckBox*>::iterator iterator_BoxOptions;
 };
 
 #endif
