@@ -72,8 +72,10 @@ void FileSystemSupportDialog::setupDialog()
     dialogWidget().tree().clear();
 
     for (const auto &fs : FileSystemFactory::map()) {
-        if (fs->type() == FileSystem::Unknown || fs->type() == FileSystem::Extended || fs->type() == FileSystem::Luks)
+        if (fs->type() == FileSystem::Type::Unknown || fs->type() == FileSystem::Type::Extended ||
+            fs->type() == FileSystem::Type::Luks || fs->type() == FileSystem::Type::Luks2) {
             continue;
+        }
 
         QTreeWidgetItem* item = new QTreeWidgetItem();
 
