@@ -27,8 +27,8 @@
 #include <ops/resizeoperation.h>
 
 #include <KConfigGroup>
-#include <KSharedConfig>
 #include <KLocalizedString>
+#include <KSharedConfig>
 
 /** Creates a new InsertDialog instance.
     @param parent the parent widget
@@ -40,7 +40,7 @@ InsertDialog::InsertDialog(QWidget* parent, Device& device, Partition& insertedP
     SizeDialogBase(parent, device, insertedPartition, destpartition.firstSector(), destpartition.lastSector()),
     m_DestPartition(destpartition)
 {
-    setWindowTitle(i18nc("@title:window", "Insert a partition"));
+    setWindowTitle(xi18nc("@title:window", "Insert a partition"));
 
     partition().move(destPartition().firstSector());
     partition().fileSystem().move(destPartition().fileSystem().firstSector());
