@@ -73,8 +73,9 @@ void NewDialog::setupDialog()
     QStringList fsNames;
     for (const auto &fs : FileSystemFactory::map()) {
         if (fs->supportCreate() != FileSystem::cmdSupportNone &&
-            fs->type() != FileSystem::Extended &&
-            fs->type() != FileSystem::Luks)
+            fs->type() != FileSystem::Type::Extended &&
+            fs->type() != FileSystem::Type::Luks &&
+            fs->type() != FileSystem::Type::Luks2)
             fsNames.append(fs->name());
     }
 
@@ -101,7 +102,7 @@ void NewDialog::setupDialog()
     dialogWidget().checkBoxEncrypt().hide();
     dialogWidget().editPassphrase().hide();
 
-    if (device().type() == Device::LVM_Device) {
+    if (device().type() == Device::Type::LVM_Device) {
         dialogWidget().comboFileSystem().removeItem(dialogWidget().comboFileSystem().findText(QStringLiteral("lvm2 pv")));
     }
 
@@ -136,14 +137,14 @@ void NewDialog::setupConnections()
 
 bool NewDialog::canMove() const
 {
-    return (device().type() == Device::LVM_Device) ? false : true;
+    return (device().type() == Device::Type::LVM_Device) ? false : true;
 }
 
 void NewDialog::accept()
 {
     if (partition().roles().has(PartitionRole::Extended)) {
         partition().deleteFileSystem();
-        partition().setFileSystem(FileSystemFactory::create(FileSystem::Extended,
+        partition().setFileSystem(FileSystemFactory::create(FileSystem::Type::Extended,
                                                             partition().firstSector(),
                                                             partition().lastSector(),
                                                             partition().sectorSize()));
@@ -152,7 +153,7 @@ void NewDialog::accept()
         FileSystem::Type innerFsType = partition().fileSystem().type();
         partition().deleteFileSystem();
         FS::luks* luksFs = dynamic_cast< FS::luks* >(
-                               FileSystemFactory::create(FileSystem::Luks,
+                               FileSystemFactory::create(FileSystem::Type::Luks,
                                                          partition().firstSector(),
                                                          partition().lastSector(),
                                                          partition().sectorSize()));
@@ -187,7 +188,7 @@ void NewDialog::onRoleChanged(bool)
     // Also make sure to set a primary's or logical's file system once the user goes back from
     // extended to any of those.
     if (r == PartitionRole::Extended)
-        updateFileSystem(FileSystem::Extended);
+        updateFileSystem(FileSystem::Type::Extended);
     else
         updateFileSystem(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText()));
 
@@ -268,7 +269,7 @@ void NewDialog::updateHideAndShow()
         dialogWidget().label().setReadOnly(false);
         dialogWidget().noSetLabel().setVisible(false);
     }
-    if (FS::luks::canEncryptType(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText())) && !partition().roles().has(PartitionRole::Extended) )
+    if (FileSystemFactory::map()[FileSystem::Type::Luks]->supportCreate() && FS::luks::canEncryptType(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText())) && !partition().roles().has(PartitionRole::Extended))
     {
         dialogWidget().checkBoxEncrypt().show();
         if (dialogWidget().checkBoxEncrypt().isChecked())
