@@ -51,7 +51,7 @@ PartPropsDialog::PartPropsDialog(QWidget* parent, Device& d, Partition& p) :
     m_Partition(p),
     m_WarnFileSystemChange(false),
     m_DialogWidget(new PartPropsWidget(this)),
-    m_ReadOnly(partition().isMounted() || partition().state() == Partition::StateCopy || partition().state() == Partition::StateRestore || d.partitionTable()->isReadOnly()),
+    m_ReadOnly(partition().isMounted() || partition().state() == Partition::State::Copy || partition().state() == Partition::State::Restore || d.partitionTable()->isReadOnly()),
     m_ForceRecreate(false)
 {
     mainLayout = new QVBoxLayout(this);
@@ -132,13 +132,27 @@ void PartPropsDialog::setupDialog()
     dialogWidget().status().setText(statusText);
     dialogWidget().uuid().setText(partition().fileSystem().uuid().isEmpty() ? xi18nc("@item uuid", "(none)") : partition().fileSystem().uuid());
 
+    if(device().partitionTable()->type() == PartitionTable::gpt){
+        QString PartitionLabel = partition().label().isEmpty() ? xi18nc("@item uuid", "(none)") : partition().label();
+        QString PartitionUUID = partition().uuid().isEmpty() ? xi18nc("@item uuid", "(none)") : partition().uuid();
+
+        dialogWidget().partitionLabel().setText(PartitionLabel);
+        dialogWidget().partitionUuid().setText(PartitionUUID);
+    }
+    else{
+        dialogWidget().partitionLabel().hide();
+        dialogWidget().partitionTextLabel().hide();
+        dialogWidget().partitionUuid().hide();
+        dialogWidget().partitionTextUuid().hide();
+    }
+
     setupFileSystemComboBox();
 
     // don't do this before the file system combo box has been set up!
     dialogWidget().label().setText(newLabel().isEmpty() ? partition().fileSystem().label() : newLabel());
     dialogWidget().capacity().setText(Capacity::formatByteSize(partition().capacity()));
 
-    if (Capacity(partition(), Capacity::Available).isValid()) {
+    if (Capacity(partition(), Capacity::Type::Available).isValid()) {
         const qint64 availPercent = (partition().fileSystem().length() - partition().fileSystem().sectorsUsed()) * 100 / partition().fileSystem().length();
 
         const QString availString = QStringLiteral("%1% - %2")
@@ -206,7 +220,7 @@ void PartPropsDialog::updateHideAndShow()
 
     // when do we show the uuid?
     const bool showUuid =
-        partition().state() != Partition::StateNew &&                           // not for new partitions
+        partition().state() != Partition::State::New &&                           // not for new partitions
         !(fs == nullptr || fs->supportGetUUID() == FileSystem::cmdSupportNone);       // not if the FS doesn't support it
 
     dialogWidget().showUuid(showUuid);
@@ -215,10 +229,10 @@ void PartPropsDialog::updateHideAndShow()
 
     // when do we show available and used capacity?
     const bool showAvailableAndUsed =
-        partition().state() != Partition::StateNew &&                           // not for new partitions
+        partition().state() != Partition::State::New &&                           // not for new partitions
         !partition().roles().has(PartitionRole::Extended) &&                    // neither for extended
         !partition().roles().has(PartitionRole::Unallocated) &&                 // or for unallocated
-        newFileSystemType() != FileSystem::Unformatted;                         // and not for unformatted file systems
+        newFileSystemType() != FileSystem::Type::Unformatted;                   // and not for unformatted file systems
 
     dialogWidget().showAvailable(showAvailableAndUsed);
     dialogWidget().showUsed(showAvailableAndUsed);
@@ -228,22 +242,22 @@ void PartPropsDialog::updateHideAndShow()
         !partition().roles().has(PartitionRole::Extended) &&                    // not for extended, they have no file system
         !partition().roles().has(PartitionRole::Unallocated) &&                 // and not for unallocated: no choice there
                                                                                 // do now show file system comboBox for open luks volumes.
-        !(partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Luks);
+        !(partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Type::Luks);
     dialogWidget().showFileSystem(showFileSystem);
 
     // when do we show the recreate file system check box?
     const bool showCheckRecreate =
         showFileSystem &&                                                       // only if we also show the file system
         partition().fileSystem().supportCreate() != FileSystem::cmdSupportNone &&  // and support creating this file system
-        partition().fileSystem().type() != FileSystem::Unknown &&               // and not for unknown file systems
-        partition().state() != Partition::StateNew &&                           // or new partitions
+        partition().fileSystem().type() != FileSystem::Type::Unknown &&         // and not for unknown file systems
+        partition().state() != Partition::State::New &&                           // or new partitions
         !partition().roles().has(PartitionRole::Luks);                          // or encrypted filesystems
 
     dialogWidget().showCheckRecreate(showCheckRecreate);
 
     // when do we show the list of partition flags?
     const bool showListFlags =
-        partition().state() != Partition::StateNew &&                           // not for new partitions
+        partition().state() != Partition::State::New &&                           // not for new partitions
         !partition().roles().has(PartitionRole::Unallocated);                   // and not for unallocated space
 
     dialogWidget().showListFlags(showListFlags);
@@ -283,7 +297,7 @@ void PartPropsDialog::setupFileSystemComboBox()
     for(const auto &fs : FileSystemFactory::map())
     {
         // If the partition isn't encrypted, skip the luks FS
-        if (fs->type() == FileSystem::Luks && partition().fileSystem().type() != FileSystem::Luks)
+        if (fs->type() == FileSystem::Type::Luks && partition().fileSystem().type() != FileSystem::Type::Luks)
             continue;
         if (partition().fileSystem().type() == fs->type() || (fs->supportCreate() != FileSystem::cmdSupportNone &&
                             partition().capacity() >= fs->minCapacity() && partition().capacity() <= fs->maxCapacity())) {
@@ -293,16 +307,16 @@ void PartPropsDialog::setupFileSystemComboBox()
                 selected = name;
 
             // If the partition isn't extended, skip the extended FS
-            if (fs->type() == FileSystem::Extended && !partition().roles().has(PartitionRole::Extended))
+            if (fs->type() == FileSystem::Type::Extended && !partition().roles().has(PartitionRole::Extended))
                 continue;
 
             // The user cannot change the filesystem back to "unformatted" once a filesystem has been created.
-            if (fs->type() == FileSystem::Unformatted) {
+            if (fs->type() == FileSystem::Type::Unformatted) {
                 // .. but if the file system is unknown to us, show the unformatted option as the currently selected one
-                if (partition().fileSystem().type() == FileSystem::Unknown) {
-                    name = FileSystem::nameForType(FileSystem::Unformatted);
+                if (partition().fileSystem().type() == FileSystem::Type::Unknown) {
+                    name = FileSystem::nameForType(FileSystem::Type::Unformatted);
                     selected = name;
-                } else if (partition().fileSystem().type() != FileSystem::Unformatted && partition().state() != Partition::StateNew)
+                } else if (partition().fileSystem().type() != FileSystem::Type::Unformatted && partition().state() != Partition::State::New)
                     continue;
             }
 
@@ -332,7 +346,7 @@ void PartPropsDialog::updatePartitionFileSystem()
 
 void PartPropsDialog::onFilesystemChanged(int)
 {
-    if (partition().state() == Partition::StateNew || warnFileSystemChange() || KMessageBox::warningContinueCancel(this,
+    if (partition().state() == Partition::State::New || warnFileSystemChange() || KMessageBox::warningContinueCancel(this,
             xi18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
                    "<para>Changing the file system on a partition already on disk will erase all its contents. If you continue now and apply the resulting operation in the main window, all data on <filename>%1</filename> will unrecoverably be lost.</para>", partition().deviceNode()),
             xi18nc("@title:window", "Really Recreate <filename>%1</filename> with File System %2?", partition().deviceNode(), dialogWidget().fileSystem().currentText()),
