@@ -31,6 +31,7 @@
 #include <QFontDatabase>
 #include <QPushButton>
 #include <QTemporaryFile>
+#include <QTextDocumentFragment>
 #include <QTextStream>
 #include <QTreeWidgetItem>
 #include <QtGlobal>
@@ -120,8 +121,8 @@ void SmartDialog::setupDialog()
                 QStringList()
                 << QLocale().toString(a.id())
                 << QStringLiteral("<b>%1</b><br/>%2").arg(a.name()).arg(st + a.desc() + QStringLiteral("</span>"))
-                << (a.failureType() == SmartAttribute::PreFailure ? xi18nc("@item:intable", "Pre-Failure") : xi18nc("@item:intable", "Old-Age"))
-                << (a.updateType() == SmartAttribute::Online ? xi18nc("@item:intable", "Online") : xi18nc("@item:intable", "Offline"))
+                << (a.failureType() == SmartAttribute::FailureType::PreFailure ? xi18nc("@item:intable", "Pre-Failure") : xi18nc("@item:intable", "Old-Age"))
+                << (a.updateType() == SmartAttribute::UpdateType::Online ? xi18nc("@item:intable", "Online") : xi18nc("@item:intable", "Offline"))
                 << QLocale().toString(a.worst())
                 << QLocale().toString(a.current())
                 << QLocale().toString(a.threshold())
@@ -130,6 +131,7 @@ void SmartDialog::setupDialog()
                 << a.value()
             );
             item->setSizeHint(0, QSize(0, 64));
+            item->setToolTip(1, QTextDocumentFragment::fromHtml(a.desc()).toPlainText());
             dialogWidget().treeSmartAttributes().addTopLevelItem(item);
         }
     } else
@@ -185,8 +187,8 @@ QString SmartDialog::toHtml() const
 
             s << "<td>" << QLocale().toString(a.id()) << "</td>\n"
               << "<td>" << QStringLiteral("<b>%1</b><br/>%2").arg(a.name()).arg(st + a.desc() + QStringLiteral("</span>")) << "</td>\n"
-              << "<td>" << (a.failureType() == SmartAttribute::PreFailure ? xi18nc("@item:intable", "Pre-Failure") : xi18nc("@item:intable", "Old-Age")) << "</td>\n"
-              << "<td>" << (a.updateType() == SmartAttribute::Online ? xi18nc("@item:intable", "Online") : xi18nc("@item:intable", "Offline")) << "</td>\n"
+              << "<td>" << (a.failureType() == SmartAttribute::FailureType::PreFailure ? xi18nc("@item:intable", "Pre-Failure") : xi18nc("@item:intable", "Old-Age")) << "</td>\n"
+              << "<td>" << (a.updateType() == SmartAttribute::UpdateType::Online ? xi18nc("@item:intable", "Online") : xi18nc("@item:intable", "Offline")) << "</td>\n"
               << "<td>" << QLocale().toString(a.worst()) << "</td>\n"
               << "<td>" << QLocale().toString(a.current()) << "</td>\n"
               << "<td>" << QLocale().toString(a.threshold()) << "</td>\n"
