@@ -16,19 +16,19 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(GUIHELPERS_H)
-
+#ifndef GUIHELPERS_H
 #define GUIHELPERS_H
 
 #include <fs/filesystem.h>
 #include <util/capacity.h>
 
+#include <vector>
+
 class QIcon;
 class QPoint;
 class QString;
 class QTreeWidget;
 
-bool checkPermissions();
 bool loadBackend();
 QIcon createFileSystemColor(FileSystem::Type type, quint32 size);
 Capacity::Unit preferredUnit();
@@ -36,9 +36,7 @@ void showColumnsContextMenu(const QPoint& p, QTreeWidget& tree);
 namespace GuiHelpers
 {
 FileSystem::Type defaultFileSystem();
-std::array< QColor, FileSystem::__lastType > fileSystemColorCodesFromSettings();
+std::vector<QColor> fileSystemColorCodesFromSettings();
 }
 
-QString suCommand();
-
 #endif
